[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[minion-cvs] minor fixes



Update of /home/minion/cvsroot/src/minion/lib/mixminion
In directory moria.mit.edu:/home/arma/work/minion/src/minion/lib/mixminion

Modified Files:
	ClientMain.py 
Log Message:
minor fixes



Index: ClientMain.py
===================================================================
RCS file: /home/minion/cvsroot/src/minion/lib/mixminion/ClientMain.py,v
retrieving revision 1.58
retrieving revision 1.59
diff -u -d -r1.58 -r1.59
--- ClientMain.py	13 Feb 2003 18:45:07 -0000	1.58
+++ ClientMain.py	14 Feb 2003 03:51:24 -0000	1.59
@@ -1991,7 +1991,7 @@
       %(cmd)s -t user@domain
   Force a fresh directory download
       %(cmd)s -D yes
   %(Send)s a message without dowloading a new directory, even if the current
   directory is out of date.
       %(cmd)s -D no -t user@domain -i data
 """.strip()
@@ -2328,7 +2328,7 @@
       %(cmd)s -t user@domain -H 6 -P 'Foo,*,Bar' -o MyBlocks -b -n 100
   Specify an explicit path.
       %(cmd)s -P 'Foo,Bar,Baz,Quux'
-  Generate 10 reply blocks without dowloading a new directory, even if the
+  Generate 10 reply blocks without downloading a new directory, even if the
   current directory is out of date.
       %(cmd)s -D no -n 10
 """.strip()
@@ -1991,7 +1991,7 @@
   Force a fresh directory download
       %(cmd)s -D yes
-  %(Send)s a message without dowloading a new directory, even if the current
+  %(Send)s a message without downloading a new directory, even if the current
   directory is out of date.
       %(cmd)s -D no -t user@domain -i data